# Honcho Simple Discord Example

This example shows how to use [Honcho](https://honcho.dev) to create a simple
Discord bot that will reply when mentioned. 

The code does not have any logic for deciding what to reply and will simply
reply with placeholder text. 

To run the bot, get a token from
[Discord](https://discord.com/developers/applications) and add it to your `.env`
file. 

```env
BOT_TOKEN=<token>
```

Then simple install the dependencies and run the bot with `python main.py`
